@@ -12,16 +12,12 @@ class BotRunner:
     bot: AsyncTeleBot
     background_jobs: list[Coroutine[None, None, None]] = field(default_factory=list)
 
-    def run_polling(self):
+    async def run_polling(self):
         """For local run / testing only"""
-
-        async def run():
-            await asyncio.gather(
-                self.bot.infinity_polling(interval=1),
-                *self.background_jobs,
-            )
-
-        asyncio.run(run())
+        await asyncio.gather(
+            self.bot.infinity_polling(interval=1),
+            *self.background_jobs,
+        )
 
     def webhook_subroute(self) -> str:
         token_hash = sha256(self.bot.token.encode("utf-8")).hexdigest()
